==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/ContactDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Contains all the contact details of the customer.
 * @property companyName The name of the company.
 * @property contactPerson The contact person name.
 * @property emailList The email list.
 * @property phone The phone number.
 */
public data class ContactDetailsArgs(
    public val companyName: Output<String>,
    public val contactPerson: Output<String>,
    public val emailList: Output<List<String>>,
    public val phone: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs =
        com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs.builder()
            .companyName(companyName.applyValue({ args0 -> args0 }))
            .contactPerson(contactPerson.applyValue({ args0 -> args0 }))
            .emailList(emailList.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .phone(phone.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ContactDetailsArgs].
 */
@PulumiTagMarker
public class ContactDetailsArgsBuilder internal constructor() {
    private var companyName: Output<String>? = null

    private var contactPerson: Output<String>? = null

    private var emailList: Output<List<String>>? = null

    private var phone: Output<String>? = null

    /**
     * @param value The name of the company.
     */
    @JvmName("hniefssplrkcmabi")
    public suspend fun companyName(`value`: Output<String>) {
        this.companyName = value
    }

    /**
     * @param value The contact person name.
     */
    @JvmName("rmpglomvgqaimipo")
    public suspend fun contactPerson(`value`: Output<String>) {
        this.contactPerson = value
    }

    /**
     * @param value The email list.
     */
    @JvmName("enibarvdoehgoptp")
    public suspend fun emailList(`value`: Output<List<String>>) {
        this.emailList = value
    }

    @JvmName("jjlqkbjjavccfjgp")
    public suspend fun emailList(vararg values: Output<String>) {
        this.emailList = Output.all(values.asList())
    }

    /**
     * @param values The email list.
     */
    @JvmName("crntjlqxwyctxegl")
    public suspend fun emailList(values: List<Output<String>>) {
        this.emailList = Output.all(values)
    }

    /**
     * @param value The phone number.
     */
    @JvmName("tivjbypcgbixyoqf")
    public suspend fun phone(`value`: Output<String>) {
        this.phone = value
    }

    /**
     * @param value The name of the company.
     */
    @JvmName("ydisnpomjecacwsq")
    public suspend fun companyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.companyName = mapped
    }

    /**
     * @param value The contact person name.
     */
    @JvmName("jpyocmegtwpgevdj")
    public suspend fun contactPerson(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contactPerson = mapped
    }

    /**
     * @param value The email list.
     */
    @JvmName("ebrxtvbwjrnerveb")
    public suspend fun emailList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emailList = mapped
    }

    /**
     * @param values The email list.
     */
    @JvmName("gbtaayahffsyqtlf")
    public suspend fun emailList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emailList = mapped
    }

    /**
     * @param value The phone number.
     */
    @JvmName("gyfixttaijljdfvy")
    public suspend fun phone(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phone = mapped
    }

    internal fun build(): ContactDetailsArgs = ContactDetailsArgs(
        companyName = companyName ?: throw PulumiNullFieldException("companyName"),
        contactPerson = contactPerson ?: throw PulumiNullFieldException("contactPerson"),
        emailList = emailList ?: throw PulumiNullFieldException("emailList"),
        phone = phone ?: throw PulumiNullFieldException("phone"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/ContactDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Contains all the contact details of the customer.
 * @property companyName The name of the company.
 * @property contactPerson The contact person name.
 * @property emailList The email list.
 * @property phone The phone number.
 */
public data class ContactDetailsArgs(
    public val companyName: Output<String>,
    public val contactPerson: Output<String>,
    public val emailList: Output<List<String>>,
    public val phone: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs =
        com.pulumi.azurenative.databoxedge.inputs.ContactDetailsArgs.builder()
            .companyName(companyName.applyValue({ args0 -> args0 }))
            .contactPerson(contactPerson.applyValue({ args0 -> args0 }))
            .emailList(emailList.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .phone(phone.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ContactDetailsArgs].
 */
@PulumiTagMarker
public class ContactDetailsArgsBuilder internal constructor() {
    private var companyName: Output<String>? = null

    private var contactPerson: Output<String>? = null

    private var emailList: Output<List<String>>? = null

    private var phone: Output<String>? = null

    /**
     * @param value The name of the company.
     */
    @JvmName("jrupqfurhqgmqcvp")
    public suspend fun companyName(`value`: Output<String>) {
        this.companyName = value
    }

    /**
     * @param value The contact person name.
     */
    @JvmName("ksqfjcgrdtupavgf")
    public suspend fun contactPerson(`value`: Output<String>) {
        this.contactPerson = value
    }

    /**
     * @param value The email list.
     */
    @JvmName("ptnfkyxsdgqrmdqw")
    public suspend fun emailList(`value`: Output<List<String>>) {
        this.emailList = value
    }

    @JvmName("uawmnurjofqckkdu")
    public suspend fun emailList(vararg values: Output<String>) {
        this.emailList = Output.all(values.asList())
    }

    /**
     * @param values The email list.
     */
    @JvmName("dwbdiqytvrfubmia")
    public suspend fun emailList(values: List<Output<String>>) {
        this.emailList = Output.all(values)
    }

    /**
     * @param value The phone number.
     */
    @JvmName("yrqqqkpsnpewtvox")
    public suspend fun phone(`value`: Output<String>) {
        this.phone = value
    }

    /**
     * @param value The name of the company.
     */
    @JvmName("klrkkyisofaabndl")
    public suspend fun companyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.companyName = mapped
    }

    /**
     * @param value The contact person name.
     */
    @JvmName("hcviuiccjhcyaxce")
    public suspend fun contactPerson(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contactPerson = mapped
    }

    /**
     * @param value The email list.
     */
    @JvmName("whamfwpmstotacxe")
    public suspend fun emailList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emailList = mapped
    }

    /**
     * @param values The email list.
     */
    @JvmName("kwabornbiwpuxxur")
    public suspend fun emailList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.emailList = mapped
    }

    /**
     * @param value The phone number.
     */
    @JvmName("eddqekjjsqkwrfob")
    public suspend fun phone(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phone = mapped
    }

    internal fun build(): ContactDetailsArgs = ContactDetailsArgs(
        companyName = companyName ?: throw PulumiNullFieldException("companyName"),
        contactPerson = contactPerson ?: throw PulumiNullFieldException("contactPerson"),
        emailList = emailList ?: throw PulumiNullFieldException("emailList"),
        phone = phone ?: throw PulumiNullFieldException("phone"),
    )
}
